==> roblox-funcaptcha-1.0.0.tgz: package/lib/session.js <==
class Session {
    api = require("./api") // Horrible way of doing this
    crypto = require("./crypto")
    http = require("./http")
    util = require("./util")
    constructor(captchaInfo) {
        this.info = captchaInfo
        this.token = captchaInfo.session_token
        this.challengeId = captchaInfo.challengeID
        this.gameVariant = captchaInfo.game_data.customGUI.game_variant
        this.gameType = captchaInfo.game_data.customGUI.gameType
        this.encrypted = captchaInfo.game_data.customGUI.encrypted_mode
        this.imgs = captchaInfo.game_data.customGUI._challenge_imgs
        this.breaker = captchaInfo.game_data.customGUI.api_breaker || "default"
        this.waves = captchaInfo.game_data.waves
        this.key = ""
        this.wave = 0
        this.answer_history = []
    }

    getImage() {
        return new Promise(async a => {
            let img = await this.http.get(this.imgs[this.wave])
            try {
                JSON.parse(img) // Image is encrypted
                if (this.key == "") {
                    this.key = await this.api.getDecryptionKey(this.info)
                    this.key = JSON.parse(this.key).decryption_key
                }
                img = await this.crypto.decrypt(img, this.key)
                img = Buffer.from(img.toString(), "base64")
            } catch (err) { console.log(err) }
            a(img)
        })
    }

    answer(answer) {
        return new Promise(async a => {
            let pos = this.util.tileToLoc(answer)
            this.answer_history.push(this.util.apiBreakers[this.breaker](pos))
            let encrypted = await this.crypto.encrypt(JSON.stringify(this.answer_history), this.token)
            let resp = await this.http.post("https://roblox-api.arkoselabs.com/fc/ca/", {
                form: {
                    session_token: this.token,
                    game_token: this.challengeId,
                    guess: encrypted
                }
            })
            resp = JSON.parse(resp)
            this.key = resp.decryption_key || ""
            this.wave++
            a(resp)
        })
    }

}

module.exports = Session

==> roblox-funcaptcha-2.0.0.tgz: package/lib/session.js <==
class Session {
    api = require("./api") // Horrible way of doing this
    crypto = require("./crypto")
    http = require("./http")
    util = require("./util")
    constructor(captchaInfo) {
        this.info = captchaInfo
        this.token = captchaInfo.session_token
        this.challengeId = captchaInfo.challengeID
        this.gameVariant = captchaInfo.game_data.game_variant
        this.gameType = captchaInfo.game_data.gameType
        this.encrypted = captchaInfo.game_data.customGUI.encrypted_mode
        this.imgs = captchaInfo.game_data.customGUI._challenge_imgs
        this.breaker = captchaInfo.game_data.customGUI.api_breaker || "default"
        this.waves = captchaInfo.game_data.waves
        this.key = ""
        this.wave = 0
        this.answer_history = []
        console.log("Using api breaker "+this.breaker)
    }

    getImage() {
        return new Promise(async a => {
            let img = await this.http({url: this.imgs[this.wave]})
            try {
                JSON.parse(img) // Image is encrypted
                if (this.key == "") {
                    this.key = await this.api.getDecryptionKey(this.info)
                    this.key = JSON.parse(this.key).decryption_key
                }
                img = await this.crypto.decrypt(img, this.key)
                img = Buffer.from(img.toString(), "base64")
            } catch (err) {
                // Image is not encrypted
                // All good!
            }
            a(img)
        })
    }

    answer(answer) {
        return new Promise(async a => {
            let pos = this.util.tileToLoc(answer)
            this.answer_history.push(this.util.apiBreakers[this.breaker](pos))
            let encrypted = await this.crypto.encrypt(JSON.stringify(this.answer_history), this.token)
            let resp = await this.http({
                url: "https://roblox-api.arkoselabs.com/fc/ca/", 
                form: {
                    session_token: this.token,
                    game_token: this.challengeId,
                    guess: encrypted
                }
            })
            resp = JSON.parse(resp)
            this.key = resp.decryption_key || ""
            this.wave++
            a(resp)
        })
    }

}

module.exports = Session
